@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013-2021, Andrés Martinelli <andmarti@gmail.com>             *
+ * Copyright (c) 2013-2025, Andrés G. Martinelli <andmarti@gmail.com>          *
  * All rights reserved.                                                        *
  *                                                                             *
  * This file is a part of sc-im                                                *
@@ -17,16 +17,16 @@
  *    documentation and/or other materials provided with the distribution.     *
  * 3. All advertising materials mentioning features or use of this software    *
  *    must display the following acknowledgement:                              *
- *    This product includes software developed by Andrés Martinelli            *
+ *    This product includes software developed by Andrés G. Martinelli         *
  *    <andmarti@gmail.com>.                                                    *
- * 4. Neither the name of the Andrés Martinelli nor the                        *
+ * 4. Neither the name of the Andrés G. Martinelli nor the                     *
  *   names of other contributors may be used to endorse or promote products    *
  *   derived from this software without specific prior written permission.     *
  *                                                                             *
- * THIS SOFTWARE IS PROVIDED BY ANDRES MARTINELLI ''AS IS'' AND ANY            *
+ * THIS SOFTWARE IS PROVIDED BY ANDRÉS G. MARTINELLI ''AS IS'' AND ANY         *
  * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED   *
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE      *
- * DISCLAIMED. IN NO EVENT SHALL ANDRES MARTINELLI BE LIABLE FOR ANY           *
+ * DISCLAIMED. IN NO EVENT SHALL ANDRÉS G. MARTINELLI BE LIABLE FOR ANY        *
  * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES  *
  * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;*
  * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND *
@@ -37,7 +37,7 @@
 
 /**
  * \file xlsx.c
- * \author Andrés Martinelli <andmarti@gmail.com>
+ * \author Andrés G. Martinelli <andmarti@gmail.com>
  * \date 2017-07-18
  * \brief TODO Write a tbrief file description.
  *
@@ -254,7 +254,9 @@ void get_sheet_data(xmlDocPtr doc, xmlDocPtr doc_strings, xmlDocPtr doc_styles)
             // inlinestring
             } else if ( s != NULL && ! strcmp(s, "inlineStr") ) {
                 char * st = NULL;
-                char * strvalue = (char *) child_node->xmlChildrenNode->xmlChildrenNode->xmlChildrenNode->content;
+                char * strvalue = NULL;
+                if (child_node->xmlChildrenNode != NULL)
+                    strvalue = (char *) child_node->xmlChildrenNode->xmlChildrenNode->xmlChildrenNode->content;
                 if (strvalue != NULL && strvalue[0] != '\0') {
                     st = str_replace (strvalue, "\"", "''");
                     clean_carrier(st); // we handle padding
@@ -391,11 +393,16 @@ int open_xlsx(char * fname, char * encoding) {
 
     // open zip file
     if ((za = zip_open(fname, 0, &err)) == NULL) {
-        zip_error_to_str(buf, sizeof(buf), err, errno);
+        // zip_error_to_str(buf, sizeof(buf), err, errno);
+        // sc_error("can't open zip archive `%s': %s", fname, buf);
+        zip_error_t error;
+        zip_error_init_with_code(&error, err);
         sc_error("can't open zip archive `%s': %s", fname, buf);
+        zip_error_fini(&error);
         return -1;
     }
 
+
     // open xl/sharedStrings.xml
     char * name = "xl/sharedStrings.xml";
     zf = zip_fopen(za, name, ZIP_FL_UNCHANGED);
